- abstrated to abstracted
  - accessibla to accessible
  - addres to address
  - apropriate to appropriate
  - arry to array
  - availabe to available
  - avaliable to available
  - becasue to because
  - correponding to corresponding
  - etablished to established
  - exeuction to execution
  - extensiable to extensible
  - fileds to fields
  - loadding to loading
  - ptototypes to prototypes
  - prococol protocol
  - requried to required
  - resoruce to resource
  - runing to running
  - uild to build

Cc: Star Zeng <star.z...@intel.com>
Cc: Feng Tian <feng.t...@intel.com>
Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Giri P Mudusuru <giri.p.mudus...@intel.com>
---
 .../BootManagerMenuApp/BootManagerMenu.c           |   6 +-
 MdeModulePkg/Application/UiApp/FrontPage.c         |   6 +-
 MdeModulePkg/Bus/Isa/IsaBusDxe/IsaBusDxe.c         |   2 +-
 MdeModulePkg/Bus/Pci/EhciDxe/UsbHcMem.c            |   2 +-
 MdeModulePkg/Bus/Pci/EhciPei/UsbHcMem.c            |   2 +-
 MdeModulePkg/Bus/Pci/PciBusDxe/PciEnumerator.c     |   6 +-
 MdeModulePkg/Bus/Pci/PciBusDxe/PciEnumerator.h     |   6 +-
 MdeModulePkg/Bus/Pci/PciBusDxe/PciLib.c            |   2 +-
 MdeModulePkg/Bus/Pci/PciSioSerialDxe/Serial.h      |   2 +-
 MdeModulePkg/Bus/Pci/PciSioSerialDxe/SerialIo.c    |   2 +-
 MdeModulePkg/Bus/Pci/UhciDxe/UsbHcMem.c            |   2 +-
 MdeModulePkg/Bus/Pci/UhciPei/UhcPeim.c             |   2 +-
 MdeModulePkg/Bus/Pci/XhciDxe/UsbHcMem.c            |   2 +-
 MdeModulePkg/Bus/Pci/XhciPei/UsbHcMem.c            |   2 +-
 MdeModulePkg/Bus/Sd/EmmcBlockIoPei/EmmcHcMem.c     |   2 +-
 MdeModulePkg/Bus/Sd/SdBlockIoPei/SdHcMem.c         |   2 +-
 MdeModulePkg/Bus/Ufs/UfsBlockIoPei/UfsHcMem.c      |   2 +-
 MdeModulePkg/Core/Dxe/DxeMain.h                    |   2 +-
 MdeModulePkg/Core/Dxe/Image/Image.c                |  14 +-
 .../Dxe/SectionExtraction/CoreSectionExtraction.c  |   2 +-
 MdeModulePkg/Core/Pei/Image/Image.c                |  34 ++---
 MdeModulePkg/Core/PiSmmCore/Dispatcher.c           | 144 ++++++++++-----------
 MdeModulePkg/Core/PiSmmCore/PiSmmCore.c            |   2 +-
 MdeModulePkg/Core/PiSmmCore/PiSmmIpl.c             |  26 ++--
 MdeModulePkg/Core/PiSmmCore/Pool.c                 |   2 +-
 MdeModulePkg/Include/Protocol/EbcVmTest.h          |   4 +-
 .../BootMaintenanceManagerUiLib/BootMaintenance.c  |   6 +-
 .../Library/BootManagerUiLib/BootManager.c         |   6 +-
 .../Universal/Console/ConSplitterDxe/ConSplitter.c |   2 +-
 MdeModulePkg/Universal/Network/ArpDxe/ArpDriver.c  |   2 +-
 MdeModulePkg/Universal/Network/ArpDxe/ArpDriver.h  |   2 +-
 .../Universal/Network/Dhcp4Dxe/Dhcp4Driver.c       |   2 +-
 .../Universal/Network/Dhcp4Dxe/Dhcp4Driver.h       |   2 +-
 MdeModulePkg/Universal/Network/Ip4Dxe/Ip4Driver.c  |   2 +-
 MdeModulePkg/Universal/Network/Ip4Dxe/Ip4Driver.h  |   4 +-
 MdeModulePkg/Universal/Network/Ip4Dxe/Ip4If.h      |   2 +-
 MdeModulePkg/Universal/Network/MnpDxe/MnpDriver.c  |   2 +-
 MdeModulePkg/Universal/Network/MnpDxe/MnpDriver.h  |   2 +-
 MdeModulePkg/Universal/Network/MnpDxe/MnpIo.c      |   2 +-
 .../Universal/Network/Tcp4Dxe/Tcp4Driver.c         |   2 +-
 .../Universal/Network/Tcp4Dxe/Tcp4Driver.h         |   2 +-
 .../Universal/Network/Tcp4Dxe/Tcp4Output.c         |   2 +-
 .../Universal/Network/Udp4Dxe/Udp4Driver.c         |   2 +-
 .../Universal/Network/Udp4Dxe/Udp4Driver.h         |   2 +-
 MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Impl.c  |  12 +-
 45 files changed, 169 insertions(+), 169 deletions(-)

diff --git a/MdeModulePkg/Application/BootManagerMenuApp/BootManagerMenu.c 
b/MdeModulePkg/Application/BootManagerMenuApp/BootManagerMenu.c
index be13410..649bdc8 100644
--- a/MdeModulePkg/Application/BootManagerMenuApp/BootManagerMenu.c
+++ b/MdeModulePkg/Application/BootManagerMenuApp/BootManagerMenu.c
@@ -738,7 +738,7 @@ BdsSetConsoleMode (
 
   if (IsSetupMode) {
     //
-    // The requried resolution and text mode is setup mode.
+    // The required resolution and text mode is setup mode.
     //
     NewHorizontalResolution = mSetupHorizontalResolution;
     NewVerticalResolution   = mSetupVerticalResolution;
@@ -794,7 +794,7 @@ BdsSetConsoleMode (
             return EFI_SUCCESS;
           } else {
             //
-            // If current text mode is different from requried text mode.  Set 
new video mode
+            // If current text mode is different from required text mode.  Set 
new video mode
             //
             for (Index = 0; Index < MaxTextMode; Index++) {
               Status = SimpleTextOut->QueryMode (SimpleTextOut, Index, 
&CurrentColumn, &CurrentRow);
@@ -819,7 +819,7 @@ BdsSetConsoleMode (
             }
             if (Index == MaxTextMode) {
               //
-              // If requried text mode is not supported, return error.
+              // If required text mode is not supported, return error.
               //
               FreePool (Info);
               return EFI_UNSUPPORTED;
diff --git a/MdeModulePkg/Application/UiApp/FrontPage.c 
b/MdeModulePkg/Application/UiApp/FrontPage.c
index 50e3597..aef0e79 100644
--- a/MdeModulePkg/Application/UiApp/FrontPage.c
+++ b/MdeModulePkg/Application/UiApp/FrontPage.c
@@ -713,7 +713,7 @@ UiSetConsoleMode (
 
   if (IsSetupMode) {
     //
-    // The requried resolution and text mode is setup mode.
+    // The required resolution and text mode is setup mode.
     //
     NewHorizontalResolution = mSetupHorizontalResolution;
     NewVerticalResolution   = mSetupVerticalResolution;
@@ -769,7 +769,7 @@ UiSetConsoleMode (
             return EFI_SUCCESS;
           } else {
             //
-            // If current text mode is different from requried text mode.  Set 
new video mode
+            // If current text mode is different from required text mode.  Set 
new video mode
             //
             for (Index = 0; Index < MaxTextMode; Index++) {
               Status = SimpleTextOut->QueryMode (SimpleTextOut, Index, 
&CurrentColumn, &CurrentRow);
@@ -794,7 +794,7 @@ UiSetConsoleMode (
             }
             if (Index == MaxTextMode) {
               //
-              // If requried text mode is not supported, return error.
+              // If required text mode is not supported, return error.
               //
               FreePool (Info);
               return EFI_UNSUPPORTED;
diff --git a/MdeModulePkg/Bus/Isa/IsaBusDxe/IsaBusDxe.c 
b/MdeModulePkg/Bus/Isa/IsaBusDxe/IsaBusDxe.c
index 7067c6e..0ac3302 100644
--- a/MdeModulePkg/Bus/Isa/IsaBusDxe/IsaBusDxe.c
+++ b/MdeModulePkg/Bus/Isa/IsaBusDxe/IsaBusDxe.c
@@ -117,7 +117,7 @@ ISA_BUS_CHILD_PRIVATE_DATA mIsaBusChildPrivateTemplate = {
 
   @retval EFI_SUCCES            The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER ChildHandle is NULL.
-  @retval EFI_OUT_OF_RESOURCES  There are not enough resources availabe to 
create
+  @retval EFI_OUT_OF_RESOURCES  There are not enough resources available to 
create
                                 the child
   @retval other                 The child handle was not created
 
diff --git a/MdeModulePkg/Bus/Pci/EhciDxe/UsbHcMem.c 
b/MdeModulePkg/Bus/Pci/EhciDxe/UsbHcMem.c
index 28be380..1b822c5 100644
--- a/MdeModulePkg/Bus/Pci/EhciDxe/UsbHcMem.c
+++ b/MdeModulePkg/Bus/Pci/EhciDxe/UsbHcMem.c
@@ -534,7 +534,7 @@ UsbHcFreeMem (
       Bit   = ((ToFree - Block->BufHost) / USBHC_MEM_UNIT) % 8;
 
       //
-      // reset associated bits in bit arry
+      // reset associated bits in bit array
       //
       for (Count = 0; Count < (AllocSize / USBHC_MEM_UNIT); Count++) {
         ASSERT (USB_HC_BIT_IS_SET (Block->Bits[Byte], Bit));
diff --git a/MdeModulePkg/Bus/Pci/EhciPei/UsbHcMem.c 
b/MdeModulePkg/Bus/Pci/EhciPei/UsbHcMem.c
index 6b37558..ee2f70b 100644
--- a/MdeModulePkg/Bus/Pci/EhciPei/UsbHcMem.c
+++ b/MdeModulePkg/Bus/Pci/EhciPei/UsbHcMem.c
@@ -462,7 +462,7 @@ UsbHcFreeMem (
       Bit   = ((ToFree - Block->Buf) / USBHC_MEM_UNIT) % 8;
 
       //
-      // reset associated bits in bit arry
+      // reset associated bits in bit array
       //
       for (Count = 0; Count < (AllocSize / USBHC_MEM_UNIT); Count++) {
         ASSERT (USB_HC_BIT_IS_SET (Block->Bits[Byte], Bit));
diff --git a/MdeModulePkg/Bus/Pci/PciBusDxe/PciEnumerator.c 
b/MdeModulePkg/Bus/Pci/PciBusDxe/PciEnumerator.c
index 469a2dd..966a9c7 100644
--- a/MdeModulePkg/Bus/Pci/PciBusDxe/PciEnumerator.c
+++ b/MdeModulePkg/Bus/Pci/PciBusDxe/PciEnumerator.c
@@ -962,7 +962,7 @@ GetMaxResourceConsumerDevice (
   @param Mem64ResStatus   Status of 64-bit memory resource node.
   @param PMem64ResStatus  Status of 64-bit Prefetchable memory resource node.
 
-  @retval EFI_SUCCESS     Successfully adjusted resoruce on host bridge.
+  @retval EFI_SUCCESS     Successfully adjusted resource on host bridge.
   @retval EFI_ABORTED     Host bridge hasn't this resource type or no resource 
be adjusted.
 
 **/
@@ -1091,7 +1091,7 @@ PciHostBridgeAdjustAllocation (
 }
 
 /**
-  Summary requests for all resource type, and contruct ACPI resource
+  Summary requests for all resource type, and construct ACPI resource
   requestor instance.
 
   @param Bridge           detecting bridge
@@ -1103,7 +1103,7 @@ PciHostBridgeAdjustAllocation (
   @param Config           Output buffer holding new constructed APCI resource 
requestor
 
   @retval EFI_SUCCESS           Successfully constructed ACPI resource.
-  @retval EFI_OUT_OF_RESOURCES  No memory availabe.
+  @retval EFI_OUT_OF_RESOURCES  No memory available.
 
 **/
 EFI_STATUS
diff --git a/MdeModulePkg/Bus/Pci/PciBusDxe/PciEnumerator.h 
b/MdeModulePkg/Bus/Pci/PciBusDxe/PciEnumerator.h
index ff164d1..68c105e 100644
--- a/MdeModulePkg/Bus/Pci/PciBusDxe/PciEnumerator.h
+++ b/MdeModulePkg/Bus/Pci/PciBusDxe/PciEnumerator.h
@@ -218,7 +218,7 @@ GetMaxResourceConsumerDevice (
   @param Mem64ResStatus   Status of 64-bit memory resource node.
   @param PMem64ResStatus  Status of 64-bit Prefetchable memory resource node.
 
-  @retval EFI_SUCCESS     Successfully adjusted resoruce on host bridge.
+  @retval EFI_SUCCESS     Successfully adjusted resource on host bridge.
   @retval EFI_ABORTED     Host bridge hasn't this resource type or no resource 
be adjusted.
 
 **/
@@ -237,7 +237,7 @@ PciHostBridgeAdjustAllocation (
   );
 
 /**
-  Summary requests for all resource type, and contruct ACPI resource
+  Summary requests for all resource type, and construct ACPI resource
   requestor instance.
 
   @param Bridge           detecting bridge
@@ -249,7 +249,7 @@ PciHostBridgeAdjustAllocation (
   @param Config           Output buffer holding new constructed APCI resource 
requestor
 
   @retval EFI_SUCCESS           Successfully constructed ACPI resource.
-  @retval EFI_OUT_OF_RESOURCES  No memory availabe.
+  @retval EFI_OUT_OF_RESOURCES  No memory available.
 
 **/
 EFI_STATUS
diff --git a/MdeModulePkg/Bus/Pci/PciBusDxe/PciLib.c 
b/MdeModulePkg/Bus/Pci/PciBusDxe/PciLib.c
index f3407bc..337a6db 100644
--- a/MdeModulePkg/Bus/Pci/PciBusDxe/PciLib.c
+++ b/MdeModulePkg/Bus/Pci/PciBusDxe/PciLib.c
@@ -522,7 +522,7 @@ PciHostBridgeResourceAllocator (
       }
 
       //
-      // Based on the all the resource tree, contruct ACPI resource node to
+      // Based on the all the resource tree, construct ACPI resource node to
       // submit the resource aperture to pci host bridge protocol
       //
       Status = ConstructAcpiResourceRequestor (
diff --git a/MdeModulePkg/Bus/Pci/PciSioSerialDxe/Serial.h 
b/MdeModulePkg/Bus/Pci/PciSioSerialDxe/Serial.h
index f147e69..a86fdd2 100644
--- a/MdeModulePkg/Bus/Pci/PciSioSerialDxe/Serial.h
+++ b/MdeModulePkg/Bus/Pci/PciSioSerialDxe/Serial.h
@@ -541,7 +541,7 @@ SerialFifoRemove (
   );
 
 /**
-  Reads and writes all avaliable data.
+  Reads and writes all available data.
 
   @param SerialDevice           The device to flush
 
diff --git a/MdeModulePkg/Bus/Pci/PciSioSerialDxe/SerialIo.c 
b/MdeModulePkg/Bus/Pci/PciSioSerialDxe/SerialIo.c
index cce61d7..c0682e9 100644
--- a/MdeModulePkg/Bus/Pci/PciSioSerialDxe/SerialIo.c
+++ b/MdeModulePkg/Bus/Pci/PciSioSerialDxe/SerialIo.c
@@ -286,7 +286,7 @@ SerialFifoRemove (
 }
 
 /**
-  Reads and writes all avaliable data.
+  Reads and writes all available data.
 
   @param SerialDevice           The device to transmit.
 
diff --git a/MdeModulePkg/Bus/Pci/UhciDxe/UsbHcMem.c 
b/MdeModulePkg/Bus/Pci/UhciDxe/UsbHcMem.c
index e42d482..dab7052 100644
--- a/MdeModulePkg/Bus/Pci/UhciDxe/UsbHcMem.c
+++ b/MdeModulePkg/Bus/Pci/UhciDxe/UsbHcMem.c
@@ -532,7 +532,7 @@ UsbHcFreeMem (
       Bit   = ((ToFree - Block->Buf) / USBHC_MEM_UNIT) % 8;
 
       //
-      // reset associated bits in bit arry
+      // reset associated bits in bit array
       //
       for (Count = 0; Count < (AllocSize / USBHC_MEM_UNIT); Count++) {
         ASSERT (USB_HC_BIT_IS_SET (Block->Bits[Byte], Bit));
diff --git a/MdeModulePkg/Bus/Pci/UhciPei/UhcPeim.c 
b/MdeModulePkg/Bus/Pci/UhciPei/UhcPeim.c
index 368b75d..180e106 100644
--- a/MdeModulePkg/Bus/Pci/UhciPei/UhcPeim.c
+++ b/MdeModulePkg/Bus/Pci/UhciPei/UhcPeim.c
@@ -3120,7 +3120,7 @@ UhcFreePool (
       StartBitPos   = (UINT8) (((Pool - TempHeaderPtr->MemoryBlockPtr) / 32) % 
8);
 
       //
-      // reset associated bits in bit arry
+      // reset associated bits in bit array
       //
       for (Index = StartBytePos, Index2 = StartBitPos, Count = 0; Count < 
(RealAllocSize / 32); Count++) {
 
diff --git a/MdeModulePkg/Bus/Pci/XhciDxe/UsbHcMem.c 
b/MdeModulePkg/Bus/Pci/XhciDxe/UsbHcMem.c
index 54c69d7..b453ea2 100644
--- a/MdeModulePkg/Bus/Pci/XhciDxe/UsbHcMem.c
+++ b/MdeModulePkg/Bus/Pci/XhciDxe/UsbHcMem.c
@@ -567,7 +567,7 @@ UsbHcFreeMem (
       Bit   = ((ToFree - Block->BufHost) / USBHC_MEM_UNIT) % 8;
 
       //
-      // reset associated bits in bit arry
+      // reset associated bits in bit array
       //
       for (Count = 0; Count < (AllocSize / USBHC_MEM_UNIT); Count++) {
         ASSERT (USB_HC_BIT_IS_SET (Block->Bits[Byte], Bit));
diff --git a/MdeModulePkg/Bus/Pci/XhciPei/UsbHcMem.c 
b/MdeModulePkg/Bus/Pci/XhciPei/UsbHcMem.c
index 663ba39..77e19cd 100644
--- a/MdeModulePkg/Bus/Pci/XhciPei/UsbHcMem.c
+++ b/MdeModulePkg/Bus/Pci/XhciPei/UsbHcMem.c
@@ -528,7 +528,7 @@ UsbHcFreeMem (
       Bit   = ((ToFree - Block->BufHost) / USBHC_MEM_UNIT) % 8;
 
       //
-      // reset associated bits in bit arry
+      // reset associated bits in bit array
       //
       for (Count = 0; Count < (AllocSize / USBHC_MEM_UNIT); Count++) {
         ASSERT (USB_HC_BIT_IS_SET (Block->Bits[Byte], Bit));
diff --git a/MdeModulePkg/Bus/Sd/EmmcBlockIoPei/EmmcHcMem.c 
b/MdeModulePkg/Bus/Sd/EmmcBlockIoPei/EmmcHcMem.c
index 073af16..b8df4c0 100644
--- a/MdeModulePkg/Bus/Sd/EmmcBlockIoPei/EmmcHcMem.c
+++ b/MdeModulePkg/Bus/Sd/EmmcBlockIoPei/EmmcHcMem.c
@@ -424,7 +424,7 @@ EmmcPeimFreeMem (
       Bit   = ((ToFree - Block->Buf) / EMMC_PEIM_MEM_UNIT) % 8;
 
       //
-      // reset associated bits in bit arry
+      // reset associated bits in bit array
       //
       for (Count = 0; Count < (AllocSize / EMMC_PEIM_MEM_UNIT); Count++) {
         ASSERT (EMMC_PEIM_MEM_BIT_IS_SET (Block->Bits[Byte], Bit));
diff --git a/MdeModulePkg/Bus/Sd/SdBlockIoPei/SdHcMem.c 
b/MdeModulePkg/Bus/Sd/SdBlockIoPei/SdHcMem.c
index 8bfe18c..882a080 100644
--- a/MdeModulePkg/Bus/Sd/SdBlockIoPei/SdHcMem.c
+++ b/MdeModulePkg/Bus/Sd/SdBlockIoPei/SdHcMem.c
@@ -424,7 +424,7 @@ SdPeimFreeMem (
       Bit   = ((ToFree - Block->Buf) / SD_PEIM_MEM_UNIT) % 8;
 
       //
-      // reset associated bits in bit arry
+      // reset associated bits in bit array
       //
       for (Count = 0; Count < (AllocSize / SD_PEIM_MEM_UNIT); Count++) {
         ASSERT (SD_PEIM_MEM_BIT_IS_SET (Block->Bits[Byte], Bit));
diff --git a/MdeModulePkg/Bus/Ufs/UfsBlockIoPei/UfsHcMem.c 
b/MdeModulePkg/Bus/Ufs/UfsBlockIoPei/UfsHcMem.c
index cc6c3d4..16741e6 100644
--- a/MdeModulePkg/Bus/Ufs/UfsBlockIoPei/UfsHcMem.c
+++ b/MdeModulePkg/Bus/Ufs/UfsBlockIoPei/UfsHcMem.c
@@ -424,7 +424,7 @@ UfsPeimFreeMem (
       Bit   = ((ToFree - Block->Buf) / UFS_PEIM_MEM_UNIT) % 8;
 
       //
-      // reset associated bits in bit arry
+      // reset associated bits in bit array
       //
       for (Count = 0; Count < (AllocSize / UFS_PEIM_MEM_UNIT); Count++) {
         ASSERT (UFS_PEIM_MEM_BIT_IS_SET (Block->Bits[Byte], Bit));
diff --git a/MdeModulePkg/Core/Dxe/DxeMain.h b/MdeModulePkg/Core/Dxe/DxeMain.h
index 743221f..60d85f0 100644
--- a/MdeModulePkg/Core/Dxe/DxeMain.h
+++ b/MdeModulePkg/Core/Dxe/DxeMain.h
@@ -2430,7 +2430,7 @@ OpenSectionStream (
                                 non-null on input, then the buffer is caller
                                 allocated.  If Buffer is NULL, then the buffer
                                 is callee allocated.  In either case, the
-                                requried buffer size is returned in 
*BufferSize.
+                                required buffer size is returned in 
*BufferSize.
   @param  BufferSize            On input, indicates the size of *Buffer if
                                 *Buffer is non-null on input.  On output,
                                 indicates the required size (allocated size if
diff --git a/MdeModulePkg/Core/Dxe/SectionExtraction/CoreSectionExtraction.c 
b/MdeModulePkg/Core/Dxe/SectionExtraction/CoreSectionExtraction.c
index 3c4f3f5..2149ea2 100644
--- a/MdeModulePkg/Core/Dxe/SectionExtraction/CoreSectionExtraction.c
+++ b/MdeModulePkg/Core/Dxe/SectionExtraction/CoreSectionExtraction.c
@@ -1166,7 +1166,7 @@ FindStreamNode (
                                 non-null on input, then the buffer is caller
                                 allocated.  If Buffer is NULL, then the buffer
                                 is callee allocated.  In either case, the
-                                requried buffer size is returned in 
*BufferSize.
+                                required buffer size is returned in 
*BufferSize.
   @param  BufferSize            On input, indicates the size of *Buffer if
                                 *Buffer is non-null on input.  On output,
                                 indicates the required size (allocated size if
diff --git a/MdeModulePkg/Core/PiSmmCore/Dispatcher.c 
b/MdeModulePkg/Core/PiSmmCore/Dispatcher.c
index 1f85ae8..324f174 100644
--- a/MdeModulePkg/Core/PiSmmCore/Dispatcher.c
+++ b/MdeModulePkg/Core/PiSmmCore/Dispatcher.c
@@ -126,17 +126,17 @@ EFI_SECURITY2_ARCH_PROTOCOL *mSecurity2 = NULL;
 
 //
 // The global variable is defined for Loading modules at fixed address feature 
to track the SMM code
-// memory range usage. It is a bit mapped array in which every bit indicates 
the correspoding 
+// memory range usage. It is a bit mapped array in which every bit indicates 
the corresponding
 // memory page available or not. 
 //
 GLOBAL_REMOVE_IF_UNREFERENCED    UINT64                
*mSmmCodeMemoryRangeUsageBitMap=NULL;
 
 /**
-  To check memory usage bit map array to figure out if the memory range in 
which the image will be loaded is available or not. If 
-  memory range is avaliable, the function will mark the correponding bits to 1 
which indicates the memory range is used.
+  To check memory usage bit map array to figure out if the memory range in 
which the image will be loaded is available or not. If
+  memory range is available, the function will mark the corresponding bits to 
1 which indicates the memory range is used.
   The function is only invoked when load modules at fixed address feature is 
enabled. 
   
-  @param  ImageBase                The base addres the image will be loaded at.
+  @param  ImageBase                The base address the image will be loaded 
at.
   @param  ImageSize                The size of the image
   
   @retval EFI_SUCCESS              The memory range the image will be loaded 
in is available
@@ -203,13 +203,13 @@ CheckAndMarkFixLoadingMemoryUsageBitMap (
    return  EFI_SUCCESS;   
 }
 /**
-  Get the fixed loadding address from image header assigned by build tool. 
This function only be called 
+  Get the fixed loading address from image header assigned by build tool. This 
function only be called
   when Loading module at Fixed address feature enabled.
   
   @param  ImageContext              Pointer to the image context structure 
that describes the PE/COFF
                                     image that needs to be examined by this 
function.
   @retval EFI_SUCCESS               An fixed loading address is assigned to 
this image by build tools .
-  @retval EFI_NOT_FOUND             The image has no assigned fixed loadding 
address.
+  @retval EFI_NOT_FOUND             The image has no assigned fixed loading 
address.
 
 **/
 EFI_STATUS
@@ -217,82 +217,82 @@ GetPeCoffImageFixLoadingAssignedAddress(
   IN OUT PE_COFF_LOADER_IMAGE_CONTEXT  *ImageContext
   )
 {
-        UINTN                              SectionHeaderOffset;
-        EFI_STATUS                         Status;
-        EFI_IMAGE_SECTION_HEADER           SectionHeader;
-        EFI_IMAGE_OPTIONAL_HEADER_UNION    *ImgHdr;
-        EFI_PHYSICAL_ADDRESS               FixLoaddingAddress;
-        UINT16                             Index;
-        UINTN                              Size; 
-        UINT16                             NumberOfSections;
-        UINT64                             ValueInSectionHeader;
-        
-        FixLoaddingAddress = 0;
-        Status = EFI_NOT_FOUND;
-       
-        //
-   // Get PeHeader pointer
-   //
-   ImgHdr = (EFI_IMAGE_OPTIONAL_HEADER_UNION *)((CHAR8* )ImageContext->Handle 
+ ImageContext->PeCoffHeaderOffset);
-        SectionHeaderOffset = (UINTN)(
+  UINTN                              SectionHeaderOffset;
+  EFI_STATUS                         Status;
+  EFI_IMAGE_SECTION_HEADER           SectionHeader;
+  EFI_IMAGE_OPTIONAL_HEADER_UNION    *ImgHdr;
+  EFI_PHYSICAL_ADDRESS               FixLoadingAddress;
+  UINT16                             Index;
+  UINTN                              Size;
+  UINT16                             NumberOfSections;
+  UINT64                             ValueInSectionHeader;
+
+  FixLoadingAddress = 0;
+  Status = EFI_NOT_FOUND;
+
+  //
+  // Get PeHeader pointer
+  //
+  ImgHdr = (EFI_IMAGE_OPTIONAL_HEADER_UNION *)((CHAR8* )ImageContext->Handle + 
ImageContext->PeCoffHeaderOffset);
+  SectionHeaderOffset = (UINTN)(
                                  ImageContext->PeCoffHeaderOffset +
                                  sizeof (UINT32) +
                                  sizeof (EFI_IMAGE_FILE_HEADER) +
                                  ImgHdr->Pe32.FileHeader.SizeOfOptionalHeader
                                  );
-   NumberOfSections = ImgHdr->Pe32.FileHeader.NumberOfSections;
-     
-   //
-   // Get base address from the first section header that doesn't point to 
code section.
-   //
-   for (Index = 0; Index < NumberOfSections; Index++) {
-     //
-     // Read section header from file
-     //
-     Size = sizeof (EFI_IMAGE_SECTION_HEADER);
-     Status = ImageContext->ImageRead (
+  NumberOfSections = ImgHdr->Pe32.FileHeader.NumberOfSections;
+
+  //
+  // Get base address from the first section header that doesn't point to code 
section.
+  //
+  for (Index = 0; Index < NumberOfSections; Index++) {
+    //
+    // Read section header from file
+    //
+    Size = sizeof (EFI_IMAGE_SECTION_HEADER);
+    Status = ImageContext->ImageRead (
                               ImageContext->Handle,
                               SectionHeaderOffset,
                               &Size,
                               &SectionHeader
                               );
-     if (EFI_ERROR (Status)) {
-       return Status;
-     }
-     
-     Status = EFI_NOT_FOUND;
-     
-     if ((SectionHeader.Characteristics & EFI_IMAGE_SCN_CNT_CODE) == 0) {
-       //
-       // Build tool will save the address in PointerToRelocations & 
PointerToLineNumbers fields in the first section header 
-       // that doesn't point to code section in image header.So there is an 
assumption that when the feature is enabled,
-       // if a module with a loading address assigned by tools, the 
PointerToRelocations & PointerToLineNumbers fields
-       // should not be Zero, or else, these 2 fileds should be set to Zero
-       //
-       ValueInSectionHeader = 
ReadUnaligned64((UINT64*)&SectionHeader.PointerToRelocations);
-       if (ValueInSectionHeader != 0) {
-         //
-         // Found first section header that doesn't point to code section in 
which uild tool saves the
-         // offset to SMRAM base as image base in PointerToRelocations & 
PointerToLineNumbers fields
-         //      
-         FixLoaddingAddress = 
(EFI_PHYSICAL_ADDRESS)(gLoadModuleAtFixAddressSmramBase + 
(INT64)ValueInSectionHeader);
-         //
-         // Check if the memory range is avaliable.
-         //
-         Status = CheckAndMarkFixLoadingMemoryUsageBitMap (FixLoaddingAddress, 
(UINTN)(ImageContext->ImageSize + ImageContext->SectionAlignment));
-         if (!EFI_ERROR(Status)) {
-           //
-           // The assigned address is valid. Return the specified loadding 
address
-           //
-           ImageContext->ImageAddress = FixLoaddingAddress;
-         }
-       }
-       break;     
-     }
-     SectionHeaderOffset += sizeof (EFI_IMAGE_SECTION_HEADER);     
-   }
-   DEBUG ((EFI_D_INFO|EFI_D_LOAD, "LOADING MODULE FIXED INFO: Loading module 
at fixed address %x, Status = %r\n", FixLoaddingAddress, Status));
-   return Status;
+    if (EFI_ERROR (Status)) {
+      return Status;
+    }
+
+    Status = EFI_NOT_FOUND;
+
+    if ((SectionHeader.Characteristics & EFI_IMAGE_SCN_CNT_CODE) == 0) {
+      //
+      // Build tool will save the address in PointerToRelocations & 
PointerToLineNumbers fields in the first section header
+      // that doesn't point to code section in image header.So there is an 
assumption that when the feature is enabled,
+      // if a module with a loading address assigned by tools, the 
PointerToRelocations & PointerToLineNumbers fields
+      // should not be Zero, or else, these 2 fields should be set to Zero
+      //
+      ValueInSectionHeader = 
ReadUnaligned64((UINT64*)&SectionHeader.PointerToRelocations);
+      if (ValueInSectionHeader != 0) {
+        //
+        // Found first section header that doesn't point to code section in 
which build tool saves the
+        // offset to SMRAM base as image base in PointerToRelocations & 
PointerToLineNumbers fields
+        //
+        FixLoadingAddress = 
(EFI_PHYSICAL_ADDRESS)(gLoadModuleAtFixAddressSmramBase + 
(INT64)ValueInSectionHeader);
+        //
+        // Check if the memory range is available.
+        //
+        Status = CheckAndMarkFixLoadingMemoryUsageBitMap (FixLoadingAddress, 
(UINTN)(ImageContext->ImageSize + ImageContext->SectionAlignment));
+        if (!EFI_ERROR(Status)) {
+          //
+          // The assigned address is valid. Return the specified loading 
address
+          //
+          ImageContext->ImageAddress = FixLoadingAddress;
+        }
+      }
+      break;
+    }
+    SectionHeaderOffset += sizeof (EFI_IMAGE_SECTION_HEADER);
+  }
+  DEBUG ((EFI_D_INFO|EFI_D_LOAD, "LOADING MODULE FIXED INFO: Loading module at 
fixed address %x, Status = %r\n", FixLoadingAddress, Status));
+  return Status;
 }
 /**
   Loads an EFI image into SMRAM.
diff --git a/MdeModulePkg/Core/PiSmmCore/PiSmmCore.c 
b/MdeModulePkg/Core/PiSmmCore/PiSmmCore.c
index 551560b..2bdb19c 100644
--- a/MdeModulePkg/Core/PiSmmCore/PiSmmCore.c
+++ b/MdeModulePkg/Core/PiSmmCore/PiSmmCore.c
@@ -256,7 +256,7 @@ SmmReadyToBootHandler (
   or if gEfiEventReadyToBootGuid is signalled.  This function unregisters the 
   Software SMIs that are nor required after SMRAM is locked and installs the 
   SMM Ready To Lock Protocol so SMM Drivers are informed that SMRAM is about 
-  to be locked.  It also verifies the the SMM CPU I/O 2 Protocol has been 
installed
+  to be locked.  It also verifies the SMM CPU I/O 2 Protocol has been installed
   and NULLs gBS and gST because they can not longer be used after SMRAM is 
locked.
 
   @param  DispatchHandle  The unique handle assigned to this handler by 
SmiHandlerRegister().
diff --git a/MdeModulePkg/Core/PiSmmCore/PiSmmIpl.c 
b/MdeModulePkg/Core/PiSmmCore/PiSmmIpl.c
index acb852b..18bec84 100644
--- a/MdeModulePkg/Core/PiSmmCore/PiSmmIpl.c
+++ b/MdeModulePkg/Core/PiSmmCore/PiSmmIpl.c
@@ -269,7 +269,7 @@ EFI_SMM_COMMUNICATE_HEADER mCommunicateHeader;
 //
 SMM_IPL_EVENT_NOTIFICATION  mSmmIplEvents[] = {
   //
-  // Declare protocol notification on the SMM Configuration protocol.  When 
this notification is etablished, 
+  // Declare protocol notification on the SMM Configuration protocol.  When 
this notification is established,
   // the associated event is immediately signalled, so the notification 
function will be executed and the 
   // SMM Configuration Protocol will be found if it is already in the handle 
database.
   //
@@ -281,7 +281,7 @@ SMM_IPL_EVENT_NOTIFICATION  mSmmIplEvents[] = {
   //
   { TRUE,  TRUE,  &gEfiDxeSmmReadyToLockProtocolGuid, 
SmmIplReadyToLockEventNotify,      &gEfiDxeSmmReadyToLockProtocolGuid, 
TPL_CALLBACK, NULL },
   //
-  // Declare event notification on EndOfDxe event.  When this notification is 
etablished, 
+  // Declare event notification on EndOfDxe event.  When this notification is 
established,
   // the associated event is immediately signalled, so the notification 
function will be executed and the 
   // SMM End Of Dxe Protocol will be found if it is already in the handle 
database.
   //
@@ -810,13 +810,13 @@ SmmIplSetVirtualAddressNotify (
 }
 
 /**
-  Get the fixed loadding address from image header assigned by build tool. 
This function only be called
+  Get the fixed loading address from image header assigned by build tool. This 
function only be called
   when Loading module at Fixed address feature enabled.
 
   @param  ImageContext              Pointer to the image context structure 
that describes the PE/COFF
                                     image that needs to be examined by this 
function.
   @retval EFI_SUCCESS               An fixed loading address is assigned to 
this image by build tools .
-  @retval EFI_NOT_FOUND             The image has no assigned fixed loadding 
address.
+  @retval EFI_NOT_FOUND             The image has no assigned fixed loading 
address.
 **/
 EFI_STATUS
 GetPeCoffImageFixLoadingAssignedAddress(
@@ -827,7 +827,7 @@ GetPeCoffImageFixLoadingAssignedAddress(
    EFI_STATUS                         Status;
    EFI_IMAGE_SECTION_HEADER           SectionHeader;
    EFI_IMAGE_OPTIONAL_HEADER_UNION    *ImgHdr;
-   EFI_PHYSICAL_ADDRESS               FixLoaddingAddress;
+   EFI_PHYSICAL_ADDRESS               FixLoadingAddress;
    UINT16                             Index;
    UINTN                              Size;
    UINT16                             NumberOfSections;
@@ -839,7 +839,7 @@ GetPeCoffImageFixLoadingAssignedAddress(
    //
    SmmCodeSize = EFI_PAGES_TO_SIZE 
(PcdGet32(PcdLoadFixAddressSmmCodePageNumber));
  
-   FixLoaddingAddress = 0;
+   FixLoadingAddress = 0;
    Status = EFI_NOT_FOUND;
    SmramBase = mCurrentSmramRange->CpuStart;
    //
@@ -879,21 +879,21 @@ GetPeCoffImageFixLoadingAssignedAddress(
        // Build tool saves the offset to SMRAM base as image base in 
PointerToRelocations & PointerToLineNumbers fields in the
        // first section header that doesn't point to code section in image 
header. And there is an assumption that when the
        // feature is enabled, if a module is assigned a loading address by 
tools, PointerToRelocations & PointerToLineNumbers
-       // fields should NOT be Zero, or else, these 2 fileds should be set to 
Zero
+       // fields should NOT be Zero, or else, these 2 fields should be set to 
Zero
        //
        ValueInSectionHeader = 
ReadUnaligned64((UINT64*)&SectionHeader.PointerToRelocations);
        if (ValueInSectionHeader != 0) {
          //
-         // Found first section header that doesn't point to code section in 
which uild tool saves the
+         // Found first section header that doesn't point to code section in 
which build tool saves the
          // offset to SMRAM base as image base in PointerToRelocations & 
PointerToLineNumbers fields
          //
-         FixLoaddingAddress = (EFI_PHYSICAL_ADDRESS)(SmramBase + 
(INT64)ValueInSectionHeader);
+         FixLoadingAddress = (EFI_PHYSICAL_ADDRESS)(SmramBase + 
(INT64)ValueInSectionHeader);
 
-         if (SmramBase + SmmCodeSize > FixLoaddingAddress && SmramBase <=  
FixLoaddingAddress) {
+         if (SmramBase + SmmCodeSize > FixLoadingAddress && SmramBase <=  
FixLoadingAddress) {
            //
-           // The assigned address is valid. Return the specified loadding 
address
+           // The assigned address is valid. Return the specified loading 
address
            //
-           ImageContext->ImageAddress = FixLoaddingAddress;
+           ImageContext->ImageAddress = FixLoadingAddress;
            Status = EFI_SUCCESS;
          }
        }
@@ -901,7 +901,7 @@ GetPeCoffImageFixLoadingAssignedAddress(
      }
      SectionHeaderOffset += sizeof (EFI_IMAGE_SECTION_HEADER);
    }
-   DEBUG ((EFI_D_INFO|EFI_D_LOAD, "LOADING MODULE FIXED INFO: Loading module 
at fixed address %x, Status = %r \n", FixLoaddingAddress, Status));
+   DEBUG ((EFI_D_INFO|EFI_D_LOAD, "LOADING MODULE FIXED INFO: Loading module 
at fixed address %x, Status = %r \n", FixLoadingAddress, Status));
    return Status;
 }
 /**
diff --git a/MdeModulePkg/Core/PiSmmCore/Pool.c 
b/MdeModulePkg/Core/PiSmmCore/Pool.c
index 53ef3e0..9d44702 100644
--- a/MdeModulePkg/Core/PiSmmCore/Pool.c
+++ b/MdeModulePkg/Core/PiSmmCore/Pool.c
@@ -47,7 +47,7 @@ SmmInitializeMemoryServices (
   }
   CurrentSmramRangesIndex = 0;
   //
-  // If Loadding Module At fixed Address feature is enabled, cache the SMRAM 
base here
+  // If Loading Module At fixed Address feature is enabled, cache the SMRAM 
base here
   //
   if (PcdGet64(PcdLoadModuleAtFixAddressEnable) != 0) {
     //
diff --git a/MdeModulePkg/Include/Protocol/EbcVmTest.h 
b/MdeModulePkg/Include/Protocol/EbcVmTest.h
index b846083..1debf1d 100644
--- a/MdeModulePkg/Include/Protocol/EbcVmTest.h
+++ b/MdeModulePkg/Include/Protocol/EbcVmTest.h
@@ -92,7 +92,7 @@ EFI_STATUS
   @param[in]  This              A pointer to the EFI_EBC_VM_TEST_PROTOCOL 
structure.
   @param[in]  AsmText           A pointer to EBC ASM text code.
   @param[out] Buffer            Buffer to store the instruction.
-  @param[out] BufferLen         Size of buffer that is requried to store data.
+  @param[out] BufferLen         Size of buffer that is required to store data.
 
   @retval EFI_UNSUPPORTED       This functionality is unsupported.
   @retval EFI_SUCCESS           Successfully convert AsmText to the 
instruction. 
@@ -113,7 +113,7 @@ EFI_STATUS
   @param[in]  This              A pointer to the EFI_EBC_VM_TEST_PROTOCOL 
structure.
   @param[out] AsmText           Contain the disasm text.
   @param[out] Buffer            Buffer to store the instruction.
-  @param[out] BufferLen         Size of buffer that is requried to store data.
+  @param[out] BufferLen         Size of buffer that is required to store data.
 
   @retval EFI_UNSUPPORTED       This functionality is unsupported.
   @retval EFI_SUCCESS           Successfully dump the executed instruction.
diff --git a/MdeModulePkg/Library/BootMaintenanceManagerUiLib/BootMaintenance.c 
b/MdeModulePkg/Library/BootMaintenanceManagerUiLib/BootMaintenance.c
index c2263e3..a190596 100644
--- a/MdeModulePkg/Library/BootMaintenanceManagerUiLib/BootMaintenance.c
+++ b/MdeModulePkg/Library/BootMaintenanceManagerUiLib/BootMaintenance.c
@@ -179,7 +179,7 @@ BmmSetConsoleMode (
 
   if (IsSetupMode) {
     //
-    // The requried resolution and text mode is setup mode.
+    // The required resolution and text mode is setup mode.
     //
     NewHorizontalResolution = mBmmSetupHorizontalResolution;
     NewVerticalResolution   = mBmmSetupVerticalResolution;
@@ -235,7 +235,7 @@ BmmSetConsoleMode (
             return EFI_SUCCESS;
           } else {
             //
-            // If current text mode is different from requried text mode.  Set 
new video mode
+            // If current text mode is different from required text mode.  Set 
new video mode
             //
             for (Index = 0; Index < MaxTextMode; Index++) {
               Status = SimpleTextOut->QueryMode (SimpleTextOut, Index, 
&CurrentColumn, &CurrentRow);
@@ -260,7 +260,7 @@ BmmSetConsoleMode (
             }
             if (Index == MaxTextMode) {
               //
-              // If requried text mode is not supported, return error.
+              // If required text mode is not supported, return error.
               //
               FreePool (Info);
               return EFI_UNSUPPORTED;
diff --git a/MdeModulePkg/Library/BootManagerUiLib/BootManager.c 
b/MdeModulePkg/Library/BootManagerUiLib/BootManager.c
index 8cc6e24..cab38ca 100644
--- a/MdeModulePkg/Library/BootManagerUiLib/BootManager.c
+++ b/MdeModulePkg/Library/BootManagerUiLib/BootManager.c
@@ -143,7 +143,7 @@ BmSetConsoleMode (
 
   if (IsSetupMode) {
     //
-    // The requried resolution and text mode is setup mode.
+    // The required resolution and text mode is setup mode.
     //
     NewHorizontalResolution = mBmSetupHorizontalResolution;
     NewVerticalResolution   = mBmSetupVerticalResolution;
@@ -199,7 +199,7 @@ BmSetConsoleMode (
             return EFI_SUCCESS;
           } else {
             //
-            // If current text mode is different from requried text mode.  Set 
new video mode
+            // If current text mode is different from required text mode.  Set 
new video mode
             //
             for (Index = 0; Index < MaxTextMode; Index++) {
               Status = SimpleTextOut->QueryMode (SimpleTextOut, Index, 
&CurrentColumn, &CurrentRow);
@@ -224,7 +224,7 @@ BmSetConsoleMode (
             }
             if (Index == MaxTextMode) {
               //
-              // If requried text mode is not supported, return error.
+              // If required text mode is not supported, return error.
               //
               FreePool (Info);
               return EFI_UNSUPPORTED;
diff --git a/MdeModulePkg/Universal/Console/ConSplitterDxe/ConSplitter.c 
b/MdeModulePkg/Universal/Console/ConSplitterDxe/ConSplitter.c
index 0d68081..ddc9717 100644
--- a/MdeModulePkg/Universal/Console/ConSplitterDxe/ConSplitter.c
+++ b/MdeModulePkg/Universal/Console/ConSplitterDxe/ConSplitter.c
@@ -2516,7 +2516,7 @@ ConSplitterGetIntersectionBetweenConOutAndStrErr (
 
   //
   // Find the intersection of the two set of modes. If they actually 
intersect, the
-  // correponding entry in the map table is set to 1.
+  // corresponding entry in the map table is set to 1.
   //
   Mode = 0;
   while (Mode < ConOutMaxMode) {
diff --git a/MdeModulePkg/Universal/Network/ArpDxe/ArpDriver.c 
b/MdeModulePkg/Universal/Network/ArpDxe/ArpDriver.c
index 81ddd62..0a02098 100644
--- a/MdeModulePkg/Universal/Network/ArpDxe/ArpDriver.c
+++ b/MdeModulePkg/Universal/Network/ArpDxe/ArpDriver.c
@@ -555,7 +555,7 @@ ArpDriverBindingStop (
 
   @retval EFI_SUCCES            The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER ChildHandle is NULL.
-  @retval EFI_OUT_OF_RESOURCES  There are not enough resources availabe to 
create
+  @retval EFI_OUT_OF_RESOURCES  There are not enough resources available to 
create
                                 the child
   @retval other                 The child handle was not created
 
diff --git a/MdeModulePkg/Universal/Network/ArpDxe/ArpDriver.h 
b/MdeModulePkg/Universal/Network/ArpDxe/ArpDriver.h
index 24b466f..ce8f8df 100644
--- a/MdeModulePkg/Universal/Network/ArpDxe/ArpDriver.h
+++ b/MdeModulePkg/Universal/Network/ArpDxe/ArpDriver.h
@@ -167,7 +167,7 @@ ArpDriverBindingStop (
 
   @retval EFI_SUCCES            The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER ChildHandle is NULL.
-  @retval EFI_OUT_OF_RESOURCES  There are not enough resources availabe to 
create
+  @retval EFI_OUT_OF_RESOURCES  There are not enough resources available to 
create
                                 the child
   @retval other                 The child handle was not created
 
diff --git a/MdeModulePkg/Universal/Network/Dhcp4Dxe/Dhcp4Driver.c 
b/MdeModulePkg/Universal/Network/Dhcp4Dxe/Dhcp4Driver.c
index 9253df2..d32b700 100644
--- a/MdeModulePkg/Universal/Network/Dhcp4Dxe/Dhcp4Driver.c
+++ b/MdeModulePkg/Universal/Network/Dhcp4Dxe/Dhcp4Driver.c
@@ -531,7 +531,7 @@ DhcpInitProtocol (
 
   @retval EFI_SUCCES            The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER ChildHandle is NULL.
-  @retval EFI_OUT_OF_RESOURCES  There are not enough resources availabe to 
create
+  @retval EFI_OUT_OF_RESOURCES  There are not enough resources available to 
create
                                 the child
   @retval other                 The child handle was not created
 
diff --git a/MdeModulePkg/Universal/Network/Dhcp4Dxe/Dhcp4Driver.h 
b/MdeModulePkg/Universal/Network/Dhcp4Dxe/Dhcp4Driver.h
index b4a63ef..6b56017 100644
--- a/MdeModulePkg/Universal/Network/Dhcp4Dxe/Dhcp4Driver.h
+++ b/MdeModulePkg/Universal/Network/Dhcp4Dxe/Dhcp4Driver.h
@@ -112,7 +112,7 @@ Dhcp4DriverBindingStop (
 
   @retval EFI_SUCCES            The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER ChildHandle is NULL.
-  @retval EFI_OUT_OF_RESOURCES  There are not enough resources availabe to 
create
+  @retval EFI_OUT_OF_RESOURCES  There are not enough resources available to 
create
                                 the child
   @retval other                 The child handle was not created
 
diff --git a/MdeModulePkg/Universal/Network/Ip4Dxe/Ip4Driver.c 
b/MdeModulePkg/Universal/Network/Ip4Dxe/Ip4Driver.c
index 20bc21f..642e453 100644
--- a/MdeModulePkg/Universal/Network/Ip4Dxe/Ip4Driver.c
+++ b/MdeModulePkg/Universal/Network/Ip4Dxe/Ip4Driver.c
@@ -800,7 +800,7 @@ ON_ERROR:
 
   @retval EFI_SUCCES            The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER ChildHandle is NULL.
-  @retval EFI_OUT_OF_RESOURCES  There are not enough resources availabe to 
create
+  @retval EFI_OUT_OF_RESOURCES  There are not enough resources available to 
create
                                 the child
   @retval other                 The child handle was not created
 
diff --git a/MdeModulePkg/Universal/Network/Ip4Dxe/Ip4Driver.h 
b/MdeModulePkg/Universal/Network/Ip4Dxe/Ip4Driver.h
index 32984ba..0dab591 100644
--- a/MdeModulePkg/Universal/Network/Ip4Dxe/Ip4Driver.h
+++ b/MdeModulePkg/Universal/Network/Ip4Dxe/Ip4Driver.h
@@ -135,7 +135,7 @@ Ip4DriverBindingStop (
   );
 
 //
-// Function ptototypes for the ServiceBinding Prococol
+// Function prototypes for the ServiceBinding Protocol
 //
 /**
   Creates a child handle and installs a protocol.
@@ -151,7 +151,7 @@ Ip4DriverBindingStop (
 
   @retval EFI_SUCCES            The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER ChildHandle is NULL.
-  @retval EFI_OUT_OF_RESOURCES  There are not enough resources availabe to 
create
+  @retval EFI_OUT_OF_RESOURCES  There are not enough resources available to 
create
                                 the child
   @retval other                 The child handle was not created
 
diff --git a/MdeModulePkg/Universal/Network/Ip4Dxe/Ip4If.h 
b/MdeModulePkg/Universal/Network/Ip4Dxe/Ip4If.h
index 6dada96..a7d4a46 100644
--- a/MdeModulePkg/Universal/Network/Ip4Dxe/Ip4If.h
+++ b/MdeModulePkg/Universal/Network/Ip4Dxe/Ip4If.h
@@ -144,7 +144,7 @@ struct _IP4_INTERFACE {
 
   //
   // IP address and subnet mask of the interface. It also contains
-  // the subnet/net broadcast address for quick access. The fileds
+  // the subnet/net broadcast address for quick access. The fields
   // are invalid if (Configured == FALSE)
   //
   IP4_ADDR                      Ip;
diff --git a/MdeModulePkg/Universal/Network/MnpDxe/MnpDriver.c 
b/MdeModulePkg/Universal/Network/MnpDxe/MnpDriver.c
index 2ddcec8..8e8c8d4 100644
--- a/MdeModulePkg/Universal/Network/MnpDxe/MnpDriver.c
+++ b/MdeModulePkg/Universal/Network/MnpDxe/MnpDriver.c
@@ -428,7 +428,7 @@ MnpDriverBindingStop (
 
   @retval EFI_SUCCES                 The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER      ChildHandle is NULL.
-  @retval EFI_OUT_OF_RESOURCES       There are not enough resources availabe to
+  @retval EFI_OUT_OF_RESOURCES       There are not enough resources available 
to
                                      create the child.
   @retval Others                     The child handle was not created.
 
diff --git a/MdeModulePkg/Universal/Network/MnpDxe/MnpDriver.h 
b/MdeModulePkg/Universal/Network/MnpDxe/MnpDriver.h
index 126d968..f83ff9f 100644
--- a/MdeModulePkg/Universal/Network/MnpDxe/MnpDriver.h
+++ b/MdeModulePkg/Universal/Network/MnpDxe/MnpDriver.h
@@ -232,7 +232,7 @@ MnpDriverBindingStop (
 
   @retval EFI_SUCCES                 The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER      ChildHandle is NULL.
-  @retval EFI_OUT_OF_RESOURCES       There are not enough resources availabe to
+  @retval EFI_OUT_OF_RESOURCES       There are not enough resources available 
to
                                      create the child.
   @retval Others                     The child handle was not created.
 
diff --git a/MdeModulePkg/Universal/Network/MnpDxe/MnpIo.c 
b/MdeModulePkg/Universal/Network/MnpDxe/MnpIo.c
index 1cbfc30..ba0f36e 100644
--- a/MdeModulePkg/Universal/Network/MnpDxe/MnpIo.c
+++ b/MdeModulePkg/Universal/Network/MnpDxe/MnpIo.c
@@ -883,7 +883,7 @@ MnpReceivePacket (
 
     if (MnpDeviceData->RxNbufCache == NULL) {
       //
-      // No availabe buffer in the buffer pool.
+      // No available buffer in the buffer pool.
       //
       return EFI_DEVICE_ERROR;
     }
diff --git a/MdeModulePkg/Universal/Network/Tcp4Dxe/Tcp4Driver.c 
b/MdeModulePkg/Universal/Network/Tcp4Dxe/Tcp4Driver.c
index 30e9406..8bdf11e 100644
--- a/MdeModulePkg/Universal/Network/Tcp4Dxe/Tcp4Driver.c
+++ b/MdeModulePkg/Universal/Network/Tcp4Dxe/Tcp4Driver.c
@@ -667,7 +667,7 @@ Tcp4DestroySocketCallback (
 
   @retval EFI_SUCCES            The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER ChildHandle is NULL.
-  @retval EFI_OUT_OF_RESOURCES  There are not enough resources availabe to 
create
+  @retval EFI_OUT_OF_RESOURCES  There are not enough resources available to 
create
                                 the child.
   @retval other                 The child handle was not created.
 
diff --git a/MdeModulePkg/Universal/Network/Tcp4Dxe/Tcp4Driver.h 
b/MdeModulePkg/Universal/Network/Tcp4Dxe/Tcp4Driver.h
index 5fe98d4..c26c3f4 100644
--- a/MdeModulePkg/Universal/Network/Tcp4Dxe/Tcp4Driver.h
+++ b/MdeModulePkg/Universal/Network/Tcp4Dxe/Tcp4Driver.h
@@ -301,7 +301,7 @@ Tcp4DestroySocketCallback (
 
   @retval EFI_SUCCES            The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER ChildHandle is NULL.
-  @retval EFI_OUT_OF_RESOURCES  There are not enough resources availabe to 
create
+  @retval EFI_OUT_OF_RESOURCES  There are not enough resources available to 
create
                                 the child.
   @retval other                 The child handle was not created.
 
diff --git a/MdeModulePkg/Universal/Network/Tcp4Dxe/Tcp4Output.c 
b/MdeModulePkg/Universal/Network/Tcp4Dxe/Tcp4Output.c
index b44e851..a55be1b 100644
--- a/MdeModulePkg/Universal/Network/Tcp4Dxe/Tcp4Output.c
+++ b/MdeModulePkg/Universal/Network/Tcp4Dxe/Tcp4Output.c
@@ -486,7 +486,7 @@ TcpGetSegmentSndQue (
 
   //
   // If SYN is set and out of the range, clear the flag.
-  // Becuase the sequence of the first byte is SEG.SEQ+1,
+  // Because the sequence of the first byte is SEG.SEQ+1,
   // adjust Offset by -1. If SYN is in the range, copy
   // one byte less.
   //
diff --git a/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Driver.c 
b/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Driver.c
index faf9ca5..525f0cb 100644
--- a/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Driver.c
+++ b/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Driver.c
@@ -294,7 +294,7 @@ Udp4DriverBindingStop (
 
   @retval EFI_SUCCES            The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER ChildHandle is NULL.
-  @retval EFI_OUT_OF_RESOURCES  There are not enough resources availabe to 
create
+  @retval EFI_OUT_OF_RESOURCES  There are not enough resources available to 
create
                                 the child
   @retval other                 The child handle was not created
 
diff --git a/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Driver.h 
b/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Driver.h
index db21270..f3d725b 100644
--- a/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Driver.h
+++ b/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Driver.h
@@ -113,7 +113,7 @@ Udp4DriverBindingStop (
 
   @retval EFI_SUCCES            The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER ChildHandle is NULL.
-  @retval EFI_OUT_OF_RESOURCES  There are not enough resources availabe to 
create
+  @retval EFI_OUT_OF_RESOURCES  There are not enough resources available to 
create
                                 the child
   @retval other                 The child handle was not created
 
diff --git a/MdeModulePkg/Core/Dxe/Image/Image.c 
b/MdeModulePkg/Core/Dxe/Image/Image.c
index 5355940..30acbb0 100644
--- a/MdeModulePkg/Core/Dxe/Image/Image.c
+++ b/MdeModulePkg/Core/Dxe/Image/Image.c
@@ -258,11 +258,11 @@ CoreReadImageFile (
   return EFI_SUCCESS;
 }
 /**
-  To check memory usage bit map arry to figure out if the memory range the 
image will be loaded in is available or not. If 
-  memory range is avaliable, the function will mark the correponding bits to 1 
which indicates the memory range is used.
+  To check memory usage bit map array to figure out if the memory range the 
image will be loaded in is available or not. If
+  memory range is available, the function will mark the corresponding bits to 
1 which indicates the memory range is used.
   The function is only invoked when load modules at fixed address feature is 
enabled. 
   
-  @param  ImageBase                The base addres the image will be loaded at.
+  @param  ImageBase                The base address the image will be loaded 
at.
   @param  ImageSize                The size of the image
   
   @retval EFI_SUCCESS              The memory range the image will be loaded 
in is available
@@ -332,13 +332,13 @@ CheckAndMarkFixLoadingMemoryUsageBitMap (
 }
 /**
 
-  Get the fixed loadding address from image header assigned by build tool. 
This function only be called
+  Get the fixed loading address from image header assigned by build tool. This 
function only be called
   when Loading module at Fixed address feature enabled.
 
   @param  ImageContext              Pointer to the image context structure 
that describes the PE/COFF
                                     image that needs to be examined by this 
function.
   @retval EFI_SUCCESS               An fixed loading address is assigned to 
this image by build tools .
-  @retval EFI_NOT_FOUND             The image has no assigned fixed loadding 
address.
+  @retval EFI_NOT_FOUND             The image has no assigned fixed loading 
address.
 
 **/
 EFI_STATUS
@@ -400,7 +400,7 @@ GetPeCoffImageFixLoadingAssignedAddress(
        // Build tool will save the address in PointerToRelocations & 
PointerToLineNumbers fields in the first section header
        // that doesn't point to code section in image header, as well as 
ImageBase field of image header. And there is an 
        // assumption that when the feature is enabled, if a module is assigned 
a loading address by tools, PointerToRelocations  
-       // & PointerToLineNumbers fields should NOT be Zero, or else, these 2 
fileds should be set to Zero
+       // & PointerToLineNumbers fields should NOT be Zero, or else, these 2 
fields should be set to Zero
        //
        ValueInSectionHeader = 
ReadUnaligned64((UINT64*)&SectionHeader.PointerToRelocations);
        if (ValueInSectionHeader != 0) {
@@ -413,7 +413,7 @@ GetPeCoffImageFixLoadingAssignedAddress(
                 ImageContext->ImageAddress = 
gLoadModuleAtFixAddressConfigurationTable.DxeCodeTopAddress + 
(INT64)(INTN)ImageContext->ImageAddress;
          }
          //
          // Check if the memory range is avaliable.
          //
          Status = CheckAndMarkFixLoadingMemoryUsageBitMap 
@@ -413,7 +413,7 @@ GetPeCoffImageFixLoadingAssignedAddress(
          }
          //
-         // Check if the memory range is avaliable.
+         // Check if the memory range is available.
          //
          Status = CheckAndMarkFixLoadingMemoryUsageBitMap 
(ImageContext->ImageAddress, (UINTN)(ImageContext->ImageSize + 
ImageContext->SectionAlignment));
        }
diff --git a/MdeModulePkg/Core/Pei/Image/Image.c 
b/MdeModulePkg/Core/Pei/Image/Image.c
index c75ef35..d659de8 100644
--- a/MdeModulePkg/Core/Pei/Image/Image.c
+++ b/MdeModulePkg/Core/Pei/Image/Image.c
@@ -139,12 +139,12 @@ GetImageReadFunction (
   return EFI_SUCCESS;
 }
 /**
-  To check memory usage bit map arry to figure out if the memory range the 
image will be loaded in is available or not. If 
-  memory range is avaliable, the function will mark the correponding bits to 1 
which indicates the memory range is used.
+  To check memory usage bit map array to figure out if the memory range the 
image will be loaded in is available or not. If
+  memory range is available, the function will mark the corresponding bits to 
1 which indicates the memory range is used.
   The function is only invoked when load modules at fixed address feature is 
enabled. 
   
   @param  Private                  Pointer to the private data passed in from 
caller
-  @param  ImageBase                The base addres the image will be loaded at.
+  @param  ImageBase                The base address the image will be loaded 
at.
   @param  ImageSize                The size of the image
   
   @retval EFI_SUCCESS              The memory range the image will be loaded 
in is available
@@ -207,7 +207,7 @@ CheckAndMarkFixLoadingMemoryUsageBitMap (
 }
 /**
 
-  Get the fixed loadding address from image header assigned by build tool. 
This function only be called
+  Get the fixed loading address from image header assigned by build tool. This 
function only be called
   when Loading module at Fixed address feature enabled.
 
   @param ImageContext              Pointer to the image context structure that 
describes the PE/COFF
@@ -215,7 +215,7 @@ CheckAndMarkFixLoadingMemoryUsageBitMap (
   @param Private                    Pointer to the private data passed in from 
caller
 
   @retval EFI_SUCCESS               An fixed loading address is assigned to 
this image by build tools .
-  @retval EFI_NOT_FOUND             The image has no assigned fixed loadding 
address.
+  @retval EFI_NOT_FOUND             The image has no assigned fixed loading 
address.
 
 **/
 EFI_STATUS
@@ -228,14 +228,14 @@ GetPeCoffImageFixLoadingAssignedAddress(
    EFI_STATUS                         Status;
    EFI_IMAGE_SECTION_HEADER           SectionHeader;
    EFI_IMAGE_OPTIONAL_HEADER_UNION    *ImgHdr;
-   EFI_PHYSICAL_ADDRESS               FixLoaddingAddress;
+   EFI_PHYSICAL_ADDRESS               FixLoadingAddress;
    UINT16                             Index;
    UINTN                              Size;
    UINT16                             NumberOfSections;
    UINT64                             ValueInSectionHeader;
  
 
-   FixLoaddingAddress = 0;
+   FixLoadingAddress = 0;
    Status = EFI_NOT_FOUND;
 
    //
@@ -244,7 +244,7 @@ GetPeCoffImageFixLoadingAssignedAddress(
    ImgHdr = (EFI_IMAGE_OPTIONAL_HEADER_UNION *)((CHAR8* )ImageContext->Handle 
+ ImageContext->PeCoffHeaderOffset);
    if (ImageContext->IsTeImage) {
      //
-     // for TE image, the fix loadding address is saved in first section 
header that doesn't point
+     // for TE image, the fix loading address is saved in first section header 
that doesn't point
      // to code section.
      //
      SectionHeaderOffset = sizeof (EFI_TE_IMAGE_HEADER);
@@ -286,7 +286,7 @@ GetPeCoffImageFixLoadingAssignedAddress(
        // for XIP PEIM, ImageBase field holds the image base address running 
on the Flash. And PointerToRelocations & PointerToLineNumbers
        // hold the image base address when it is shadow to the memory. And 
there is an assumption that when the feature is enabled, if a
        // module is assigned a loading address by tools, PointerToRelocations 
& PointerToLineNumbers fields should NOT be Zero, or
-       // else, these 2 fileds should be set to Zero
+       // else, these 2 fields should be set to Zero
        //
        ValueInSectionHeader = 
ReadUnaligned64((UINT64*)&SectionHeader.PointerToRelocations);
        if (ValueInSectionHeader != 0) {
@@ -296,32 +296,32 @@ GetPeCoffImageFixLoadingAssignedAddress(
          if ((INT64)PcdGet64(PcdLoadModuleAtFixAddressEnable) > 0) {
            //
            // When LMFA feature is configured as Load Module at Fixed Absolute 
Address mode, PointerToRelocations & PointerToLineNumbers field
-           // hold the absolute address of image base runing in memory
+           // hold the absolute address of image base running in memory
            //
-           FixLoaddingAddress = ValueInSectionHeader;
+           FixLoadingAddress = ValueInSectionHeader;
          } else {
            //
            // When LMFA feature is configured as Load Module at Fixed offset 
mode, PointerToRelocations & PointerToLineNumbers field
            // hold the offset relative to a platform-specific top address.
            //
-           FixLoaddingAddress = 
(EFI_PHYSICAL_ADDRESS)(Private->LoadModuleAtFixAddressTopAddress + 
(INT64)ValueInSectionHeader);
+           FixLoadingAddress = 
(EFI_PHYSICAL_ADDRESS)(Private->LoadModuleAtFixAddressTopAddress + 
(INT64)ValueInSectionHeader);
          }
          //
          // Check if the memory range is avaliable.
          //
-         Status = CheckAndMarkFixLoadingMemoryUsageBitMap (Private, 
FixLoaddingAddress, (UINT32) ImageContext->ImageSize);
+         Status = CheckAndMarkFixLoadingMemoryUsageBitMap (Private, 
FixLoadingAddress, (UINT32) ImageContext->ImageSize);
          if (!EFI_ERROR(Status)) {
            //
-           // The assigned address is valid. Return the specified loadding 
address
+           // The assigned address is valid. Return the specified loading 
address
            //
-           ImageContext->ImageAddress = FixLoaddingAddress;
+           ImageContext->ImageAddress = FixLoadingAddress;
          }
        }
        break;
      }
      SectionHeaderOffset += sizeof (EFI_IMAGE_SECTION_HEADER);
    }
-   DEBUG ((EFI_D_INFO|EFI_D_LOAD, "LOADING MODULE FIXED INFO: Loading module 
at fixed address 0x%11p. Status= %r \n", (VOID *)(UINTN)FixLoaddingAddress, 
Status));
+   DEBUG ((EFI_D_INFO|EFI_D_LOAD, "LOADING MODULE FIXED INFO: Loading module 
at fixed address 0x%11p. Status= %r \n", (VOID *)(UINTN)FixLoadingAddress, 
Status));
    return Status;
@@ -296,32 +296,32 @@ GetPeCoffImageFixLoadingAssignedAddress(
          }
          //
-         // Check if the memory range is avaliable.
+         // Check if the memory range is available.
          //
 }
 /**
diff --git a/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Impl.c 
b/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Impl.c
index df95077..b258439 100644
--- a/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Impl.c
+++ b/MdeModulePkg/Universal/Network/Udp4Dxe/Udp4Impl.c
@@ -200,10 +200,10 @@ Udp4DeliverDgram (
   );
 
 /**
-  This function demultiplexes the received udp datagram to the apropriate 
instances.
+  This function demultiplexes the received udp datagram to the appropriate 
instances.
 
   @param[in]  Udp4Service            Pointer to the udp service context data.
-  @param[in]  NetSession             Pointer to the EFI_NET_SESSION_DATA 
abstrated from
+  @param[in]  NetSession             Pointer to the EFI_NET_SESSION_DATA 
abstracted from
                                      the received datagram.
   @param[in]  Packet                 Pointer to the buffer containing the 
received udp
                                      datagram.
@@ -1586,10 +1586,10 @@ Udp4DeliverDgram (
 
 
 /**
-  This function demultiplexes the received udp datagram to the apropriate 
instances.
+  This function demultiplexes the received udp datagram to the appropriate 
instances.
 
   @param[in]  Udp4Service            Pointer to the udp service context data.
-  @param[in]  NetSession             Pointer to the EFI_NET_SESSION_DATA 
abstrated from
+  @param[in]  NetSession             Pointer to the EFI_NET_SESSION_DATA 
abstracted from
                                      the received datagram.
   @param[in]  Packet                 Pointer to the buffer containing the 
received udp
                                      datagram.
@@ -1707,7 +1707,7 @@ Udp4SendPortUnreach (
   IpSender = IpIoFindSender (&IpIo, NetSession->IpVersion, &NetSession->Dest);
   if (IpSender == NULL) {
     //
     // No apropriate sender, since we cannot send out the ICMP message through
     // the default zero station address IP instance, abort.
     //
     return;
@@ -1716,7 +1716,7 @@ Udp4SendPortUnreach (
   IpHdr = NetSession->IpHdr.Ip4Hdr;
 
   //
-  // Calculate the requried length of the icmp error message.
+  // Calculate the required length of the icmp error message.
   //
   Len = sizeof (IP4_ICMP_ERROR_HEAD) + (EFI_IP4_HEADER_LEN (IpHdr) -
         sizeof (IP4_HEAD)) + ICMP_ERROR_PACKET_LENGTH;
@@ -1707,7 +1707,7 @@ Udp4SendPortUnreach (
   if (IpSender == NULL) {
     //
-    // No apropriate sender, since we cannot send out the ICMP message through
+    // No appropriate sender, since we cannot send out the ICMP message through
     // the default zero station address IP instance, abort.
     //
-- 
2.9.0.windows.1

_______________________________________________
edk2-devel mailing list
edk2-devel@lists.01.org
https://lists.01.org/mailman/listinfo/edk2-devel

Reply via email to